# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Colorado."""


ADAMS = "001"
ALAMOSA = "003"
ARAPAHOE = "005"
ARCHULETA = "007"
BACA = "009"
BENT = "011"
BOULDER = "013"
BROOMFIELD = "014"
CHAFFEE = "015"
CHEYENNE = "017"
CLEAR_CREEK = "019"
CONEJOS = "021"
COSTILLA = "023"
CROWLEY = "025"
CUSTER = "027"
DELTA = "029"
DENVER = "031"
DOLORES = "033"
DOUGLAS = "035"
EAGLE = "037"
EL_PASO = "041"
ELBERT = "039"
FREMONT = "043"
GARFIELD = "045"
GILPIN = "047"
GRAND = "049"
GUNNISON = "051"
HINSDALE = "053"
HUERFANO = "055"
JACKSON = "057"
JEFFERSON = "059"
KIOWA = "061"
KIT_CARSON = "063"
LA_PLATA = "067"
LAKE = "065"
LARIMER = "069"
LAS_ANIMAS = "071"
LINCOLN = "073"
LOGAN = "075"
MESA = "077"
MINERAL = "079"
MOFFAT = "081"
MONTEZUMA = "083"
MONTROSE = "085"
MORGAN = "087"
OTERO = "089"
OURAY = "091"
PARK = "093"
PHILLIPS = "095"
PITKIN = "097"
PROWERS = "099"
PUEBLO = "101"
RIO_BLANCO = "103"
RIO_GRANDE = "105"
ROUTT = "107"
SAGUACHE = "109"
SAN_JUAN = "111"
SAN_MIGUEL = "113"
SEDGWICK = "115"
SUMMIT = "117"
TELLER = "119"
WASHINGTON = "121"
WELD = "123"
YUMA = "125"



"""Utility functions for downloading, graphing and analyzing multiple years of ACS data."""

from collections import defaultdict
import pandas as pd

import matplotlib.pyplot as plt
from matplotlib.ticker import FuncFormatter

import censusdis.data as ced
from censusdis.datasets import ACS1, ACS3, ACS5

import re

from typing import List, Optional, Union, Iterable, Callable, Dict


def is_variable_column(
    col: str,
    download_variables: Optional[Union[str, Iterable[str]]],
    group: Optional[str],
) -> bool:
    """
    Determine whether a column is a Census variable.

    There are two ways to download data from the Census Bureau: as a group (i.e. table) or
    as a list of variables. The way to test whether a column of the resulting
    df is a variable depends on whether the data was requested by group or variable.

    In practice this function is used to drop columns that contain metadata that I don't need.
    We want columns like "B01001_001E" and not like "STATE"
    """
    if group and col.startswith(group):
        return True
    if download_variables and col in download_variables:
        return True

    return False


# This function is based on the notebook linked to in this github issue:
# https://github.com/censusdis/censusdis/issues/325
def name_mapper(
    dataset: str,
    vintage: int,
    download_variables: Optional[Union[str, Iterable[str]]],
    group: Optional[str],
) -> Callable[[str], str]:
    """Return a function that converts an ACS variable to its label."""

    def inner(variable: str) -> str:
        """Map from the variables we got back to their labels."""
        if is_variable_column(variable, download_variables, group):
            # Look up details of the particular variable:
            vars = ced.variables.search(
                dataset, vintage, group_name=group, name=variable
            )
            # Census uses !! to indicate nesting of Labels. Ex. 'Estimate!!Total:'
            # We care about the last part.
            label = vars.iloc[0]["LABEL"]
            label = re.split(r"!!", label)[-1]

            # Starting in 2020 Labels which are parents of other Labels have a : as a suffix.
            # See an example here: https://data.census.gov/table?q=country%20of%20birth&g=9700000US3612510
            # (Ex. "Total:", "Asia:", "Eastern Asia:", "China:")
            # For my purposes, it is better to drop this trailing :
            return label[:-1] if label[-1] == ":" else label
        else:
            # Not in the group we are interested in, so leave it as is.
            return variable

    return inner


def get_unique_labels_for_variable(
    acs: str, variable: str, years: List[int]
) -> Dict[str, List[int]]:
    """
    Return all labels the ACS has used for a given variable.

    Note that the ACS sometimes changes the labels of a variable. Sometimes these changes are minor,
    and sometimes the same variable is used for something completely different. This function is designed to
    facilitate doing this check over multiple years.

    For example, B08006_017E in 2005 had label 'Estimate!!Total!!Motorcycle'. But in 2006 it switched to
    'Estimate!!Total!!Worked at home'. And in 2019 it changed to 'Estimate!!Total:!!Worked from home'.

    To reduce false positives labels are converted to lower case prior to comparison ("Race" is
    inconsistently capitalized over the years). Also, all ":" are removed prior to comparison so that
    "estimate!!total:!!native" is the same as "estimate!!total!!native".

    Parameters
    ----------
    - acs: The ACS to use. Ex. censusdis.datasets.ACS1
    - variable: The variable in question. Ex. 'B01001_001E'
    - years: An iterable of years to use. Ex. [2005, 2006, 2007]

    Returns
    -------
    - A dict where each key is a label, and each value is a list of years that key has been used.

    Note: If the dict returned is of length 1, then the variable has only ever had 1 label.
    """
    labels = defaultdict(list)

    for year in years:
        label = ced.variables.get(acs, year, variable)["label"].lower()
        label = label.replace(":", "")

        labels[label].append(year)

    return labels


class VariableMistmatchOverTimeError(Exception):
    """Raised when an ACS variable has had multiple labels over time."""

    pass


def warn_variable_changes(
    df: pd.DataFrame,
    dataset: str,
    vintages: List[int],
    download_variables: Optional[Union[str, Iterable[str]]],
    group: Optional[str],
    prompt: bool,
) -> None:
    """
    Issue a warning when an ACS variable has had multiple labels over the years.

    In the ACS, Sometimes the same variable is used for different things in different years.
    For example in 2005 `B08006_017E` was used for "Estimate!!Total!!Motorcycle". But in 2006 it
    changed to "Estimate!!Total!!Worked at home" and in 2019 it changed to "Estimate!!Total:!!Worked from home".
    This code alerts users of any variables which have had different labels over time.

    This function always emits a warning if it encounters that situation. If prompt is True
    then it also prompts the user to confirm whether they want to continue with the download.
    """
    years = df["Year"].unique()

    for col in df.columns:
        if not is_variable_column(col, download_variables, group):
            continue

        unique_labels_for_variable = get_unique_labels_for_variable(
            dataset, col, vintages
        )

        if len(unique_labels_for_variable) > 1:
            print(f"Warning: {col} has had multiple labels over the selected years:")
            for label, years in unique_labels_for_variable.items():
                print(f"\t'{label}' in {years}")
            if prompt:
                if input("Continue downloading dataset (y/n)?") != "y":
                    raise VariableMistmatchOverTimeError()


def download_multiyear(
    dataset: str,
    vintages: List[int],
    download_variables: Optional[Union[str, Iterable[str]]] = None,
    *,
    group: Optional[str] = None,
    rename_vars: bool = True,
    drop_cols: bool = True,
    prompt: bool = True,
    **kwargs,
) -> pd.DataFrame:
    """
    Download multiple years of ACS data into a single dataframe.

    Variables can be specified individually by `download_variables` or as a table by `group`.

    Parameters
    ----------
    dataset
        Must be one of `censusdis.datasets.ACS1`, `censudis.datasets.ACS3` or `censusdis.datasets.ACS5`.
    vintages
        A list of years to download data for.
    download_variables
        The census variables to download, for example `["NAME", "B01001_001E"]`.
    group
        One or more groups (as defined by the U.S. Census for the data set)
        whose variable values should be downloaded.
    rename_vars
        If True, rename the columns from variables (ex. "B01001_001E") to their labels (ex. "Total").
        The labels for the last year are used.
    drop_cols
        If True, drop cols that do not contain variables or the year (ex. geography columns).
    prompt
        This function emits a warning each time a downloaded variable has had multiple labels over time.
        If True, prompt the user whether they want to continue downloading the dataset despite the differences.
    **kwargs
        Geography parameters passed directly to `ced.download`.

    Returns
    -------
    A dataframe.

    Examples
    --------
    # Download the population by nativity in Great Neck School District, NY.
    from censusdis.multiyear import download_multiyear
    from censusdis.datasets import ACS5
    from censusdis.states import NY

    # Download the entire table.
    df = download_multiyear(
        dataset=ACS5,
        vintages=[2009, 2014, 2019],
        group="B05012",
        prompt=False,
        state=NY,
        school_district_unified="12510",
    )

    # Downloaded selected variables.
    df = download_multiyear(
        dataset=ACS5,
        vintages=[2009, 2014, 2019],
        download_variables=["B05006_049E", "B05006_060E", "B05006_054E"],
        state=NY,
        school_district_unified="12510",
        drop_cols=True,
    )
    """
    if dataset not in [ACS1, ACS3, ACS5]:
        raise ValueError(
            "Dataset must be one of `censusdis.datasets.ACS1`, `censusdis.datasets.ACS3` or `censusdis.datasets.ACS5`"
        )

    if (download_variables is None and group is None) or (
        download_variables is not None and group is not None
    ):
        raise ValueError("Exactly one of download_variables and group must be set.")

    df = None

    for vintage in vintages:
        # This loop can take a while, so provide feedback to the user
        print(".", end="", flush=True)

        df_new = ced.download(
            dataset=dataset,
            vintage=vintage,
            download_variables=download_variables,
            group=group,
            **kwargs,
        )

        df_new["Year"] = vintage

        if df is None:
            df = df_new
        else:
            df = pd.concat([df, df_new])

    warn_variable_changes(df, dataset, vintages, download_variables, group, prompt)

    if drop_cols:
        df = df[
            [
                col
                for col in df.columns
                if is_variable_column(col, download_variables, group) or col == "Year"
            ]
        ]

    if rename_vars:
        df = df.rename(
            columns=name_mapper(
                dataset=dataset,
                vintage=vintages[-1],
                download_variables=download_variables,
                group=group,
            )
        )

    df = df.reset_index(drop=True)
    return df


def graph_multiyear(
    df: pd.DataFrame,
    title: str = "",
    yaxis_title: str = "",
    y_cols: Optional[Iterable[str]] = None,
) -> None:
    """
    Create a (multi-line) graph of time series data.

    Parameters
    ----------
    df
        Must have a column called 'Year' which will serve as the x-axis.
    title
        Title for the graph.
    yaxis_title
        Title for the y-axis.
    y_cols
        A list of columns in `df` to create lines for. If None then will graph all
        columns except "Year".

    Returns
    -------
    NoneType

    Examples
    --------
    # Graph the population by nativity in Great Neck School District, NY.
    from censusdis.multiyear import download_multiyear, graph_multiyear
    from censusdis.datasets import ACS5
    from censusdis.states import NY

    df = download_multiyear(
        dataset=ACS5,
        vintages=[2010, 2015, 2020],
        group="B05012",
        state=NY,
        school_district_unified="12510",
    )
    graph_multiyear(
        df,
        "Population by Nativity in Great Neck School District",
        "Population",
        ["Total", "Native", "Foreign-Born"],
    )
    """

    # Define a function to format the y-axis with commas
    def format_yaxis(value, tick_position):
        return f"{value:,.0f}"

    if not y_cols:
        y_cols = [col for col in df.columns if col != "Year"]

    colorblind_palette = [
        "#E69F00",
        "#56B4E9",
        "#009E73",
        "#F0E442",
        "#0072B2",
        "#D55E00",
        "#CC79A7",
        "#999999",
        "#E41A1C",
    ]

    for idx, y_col in enumerate(y_cols):
        plt.plot(
            df["Year"],
            df[y_col],
            label=y_col,
            marker="o",
            color=colorblind_palette[idx],
        )

    # Explicitly set the x-axis ticks to match the actual years in the data
    plt.xticks(ticks=df["Year"], labels=df["Year"], rotation=-45)

    # Apply comma formatting to the y-axis
    plt.gca().yaxis.set_major_formatter(FuncFormatter(format_yaxis))

    plt.xlabel("Year")
    plt.ylabel(yaxis_title)
    plt.title(title)
    plt.legend(loc="center left", bbox_to_anchor=(1, 0.5))
    plt.show()


def pct_change_multiyear(df: pd.DataFrame) -> pd.DataFrame:
    r"""
    Convert a multi-year dataframe from raw counts to percent change.

    Essentially runs pd.DataFrame.pct_change on all columns of the dataframe except the "Year" column.
    Rounds the results to 1 decimal point.

    Parameters
    ----------
    df
        Must have a column called 'Year'.

    Returns
    -------
    A Dataframe

    Examples
    --------
    # Graph the percent change in the population by nativity in Great Neck School District, NY.
    from censusdis.multiyear import (
        download_multiyear,
        pct_change_multiyear,
        graph_multiyear,
    )
    from censusdis.datasets import ACS5
    from censusdis.states import NY

    df = download_multiyear(
        dataset=ACS5,
        vintages=[2010, 2015, 2020],
        group="B05012",
        prompt=False,
        state=NY,
        school_district_unified="12510",
    )

    df = pct_change_multiyear(df)
    print(df)

    graph_multiyear(
        df,
        "Percent Change in Population by Nativity\nGreat Neck School District, NY",
        "Percent Change",
    )
    """
    years = df["Year"]

    df = df.pct_change() * 100
    df = df.round(1)

    df["Year"] = years

    return df



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Oklahoma."""


ACHILLE_TOWN = "00100"
ADA_CITY = "00200"
ADAIR_TOWN = "00250"
ADAMS_CDP = "00300"
ADAMSON_CDP = "00350"
ADDINGTON_TOWN = "00450"
AFTON_TOWN = "00600"
AGRA_TOWN = "00700"
AKINS_CDP = "00900"
ALBANY_CDP = "00950"
ALBION_TOWN = "01050"
ALDERSON_TOWN = "01150"
ALEX_TOWN = "01250"
ALINE_TOWN = "01350"
ALLEN_TOWN = "01400"
ALTUS_CITY = "01700"
ALVA_CITY = "01800"
AMBER_TOWN = "01900"
AMES_TOWN = "01950"
AMORITA_TOWN = "02000"
ANADARKO_CITY = "02050"
ANTLERS_CITY = "02250"
APACHE_TOWN = "02300"
ARAPAHO_TOWN = "02500"
ARCADIA_TOWN = "02550"
ARDMORE_CITY = "02600"
ARKOMA_TOWN = "02650"
ARMSTRONG_TOWN = "02750"
ARNETT_TOWN = "02800"
ARPELAR_CDP = "02900"
ASHER_TOWN = "03000"
ASHLAND_TOWN = "03050"
ATOKA_CITY = "03300"
ATWOOD_TOWN = "03350"
AVANT_TOWN = "03500"
AVARD_CDP = "03550"
BACHE_CDP = "03750"
BADGER_LEE_CDP = "03815"
BAKER_CDP = "03900"
BALLOU_CDP = "04075"
BARBER_CDP = "04200"
BARNSDALL_CITY = "04250"
BARON_CDP = "04350"
BARTLESVILLE_CITY = "04450"
BEARDEN_TOWN = "04700"
BEAVER_TOWN = "04750"
BEE_CDP = "04950"
BEGGS_CITY = "05000"
BELFONTE_CDP = "05070"
BELL_CDP = "05090"
BENNINGTON_TOWN = "05400"
BENTLEY_CDP = "05450"
BERNICE_TOWN = "05550"
BESSIE_TOWN = "05650"
BETHANY_CITY = "05700"
BETHEL_ACRES_TOWN = "05800"
BIG_CABIN_TOWN = "05900"
BILLINGS_TOWN = "06100"
BINGER_TOWN = "06200"
BISON_CDP = "06350"
BIXBY_CITY = "06400"
BLACKBURN_TOWN = "06450"
BLACKGUM_CDP = "06500"
BLACKWELL_CITY = "06600"
BLAIR_TOWN = "06650"
BLANCHARD_CITY = "06700"
BLANCO_CDP = "06750"
BLUE_CDP = "06900"
BLUEJACKET_TOWN = "06950"
BOISE_CITY_CITY = "07300"
BOKCHITO_TOWN = "07350"
BOKOSHE_TOWN = "07450"
BOLEY_TOWN = "07500"
BOSWELL_TOWN = "07750"
BOWLEGS_TOWN = "07950"
BOWRING_CDP = "08000"
BOX_CDP = "08050"
BOYNTON_TOWN = "08150"
BRADLEY_TOWN = "08300"
BRAGGS_TOWN = "08400"
BRAMAN_TOWN = "08450"
BRAY_TOWN = "08550"
BRECKENRIDGE_TOWN = "08600"
BRENT_CDP = "08650"
BRIARTOWN_CDP = "08700"
BRIDGE_CREEK_TOWN = "08725"
BRIDGEPORT_CITY = "08750"
BRIGGS_CDP = "08775"
BRISTOW_CITY = "08900"
BROKEN_ARROW_CITY = "09050"
BROKEN_BOW_CITY = "09100"
BROMIDE_TOWN = "09150"
BROOKSVILLE_TOWN = "09400"
BRUSH_CREEK_CDP = "09612"
BRUSHY_CDP = "09650"
BRYANT_CDP = "09700"
BUFFALO_TOWN = "09850"
BUG_TUSSLE_CDP = "09875"
BULL_HOLLOW_CDP = "09887"
BUNCH_CDP = "09900"
BURBANK_TOWN = "09950"
BURLINGTON_TOWN = "10050"
BURNEYVILLE_CDP = "10150"
BURNS_FLAT_TOWN = "10250"
BUSHYHEAD_CDP = "10400"
BUTLER_CDP = "10460"
BUTLER_TOWN = "10450"
BYARS_TOWN = "10550"
BYNG_TOWN = "10600"
BYRON_TOWN = "10650"
CACHE_CITY = "10700"
CADDO_TOWN = "10800"
CALERA_TOWN = "10950"
CALUMET_TOWN = "11050"
CALVIN_TOWN = "11100"
CAMARGO_TOWN = "11150"
CAMERON_TOWN = "11300"
CANADIAN_SHORES_CDP = "11530"
CANADIAN_TOWN = "11450"
CANEY_CDP = "11562"
CANEY_RIDGE_CDP = "11575"
CANEY_TOWN = "11550"
CANTON_TOWN = "11600"
CANUTE_TOWN = "11650"
CAPRON_TOWN = "11750"
CARLISLE_CDP = "11975"
CARLTON_LANDING_TOWN = "11990"
CARMEN_TOWN = "12000"
CARNEGIE_TOWN = "12050"
CARNEY_TOWN = "12100"
CARRIER_TOWN = "12200"
CARTER_TOWN = "12300"
CARTWRIGHT_CDP = "12550"
CASHION_TOWN = "12650"
CASTLE_TOWN = "12750"
CATOOSA_CITY = "12900"
CAVE_SPRING_CDP = "12910"
CAYUGA_CDP = "12915"
CEDAR_CREST_CDP = "12930"
CEDAR_LAKE_CDP = "12937"
CEDAR_VALLEY_CITY = "12960"
CEMENT_TOWN = "13000"
CENTRAHOMA_CITY = "13100"
CENTRAL_HIGH_TOWN = "13135"
CHANCE_CDP = "13475"
CHANDLER_CITY = "13500"
CHATTANOOGA_TOWN = "13600"
CHECOTAH_CITY = "13650"
CHELSEA_TOWN = "13700"
CHEROKEE_CITY = "13750"
CHERRY_TREE_CDP = "13775"
CHESTER_CDP = "13800"
CHEWEY_CDP = "13850"
CHEYENNE_TOWN = "13900"
CHICKASHA_CITY = "13950"
CHOCTAW_CITY = "14200"
CHOUTEAU_TOWN = "14300"
CHRISTIE_CDP = "14350"
CIMARRON_CITY_TOWN = "14500"
CLAREMORE_CITY = "14700"
CLARITA_CDP = "14750"
CLARKSVILLE_CDP = "14800"
CLAYTON_TOWN = "14900"
CLEARVIEW_TOWN = "15050"
CLEO_SPRINGS_TOWN = "15300"
CLEORA_CDP = "15250"
CLEVELAND_CITY = "15350"
CLINTON_CITY = "15400"
CLOUD_CREEK_CDP = "15625"
COALGATE_CITY = "15800"
COLBERT_TOWN = "16050"
COLCORD_TOWN = "16100"
COLE_TOWN = "16200"
COLEMAN_CDP = "16250"
COLLINSVILLE_CITY = "16350"
COLONY_TOWN = "16400"
COMANCHE_CITY = "16450"
COMMERCE_CITY = "16500"
CONNERVILLE_CDP = "16700"
COOKSON_CDP = "16950"
COOPERTON_TOWN = "17050"
COPAN_TOWN = "17100"
COPELAND_CDP = "17110"
CORN_TOWN = "17300"
CORNISH_TOWN = "17350"
COTTONWOOD_CDP = "17450"
COUNCIL_HILL_TOWN = "17550"
COVINGTON_TOWN = "17700"
COWETA_CITY = "17800"
COWLINGTON_TOWN = "17850"
COYLE_TOWN = "17950"
CRESCENT_SPRINGS_CDP = "18275"
CRESCENT_CITY = "18250"
CROMWELL_TOWN = "18450"
CROWDER_TOWN = "18550"
CUMBERLAND_CDP = "18750"
CUSHING_CITY = "18850"
CUSTER_CITY_TOWN = "18950"
CYRIL_TOWN = "19000"
DACOMA_TOWN = "19050"
DALE_CDP = "19150"
DAVENPORT_TOWN = "19350"
DAVIDSON_TOWN = "19400"
DAVIS_CITY = "19450"
DEER_CREEK_TOWN = "19650"
DEER_LICK_CDP = "19665"
DEL_CITY_CITY = "19900"
DELAWARE_TOWN = "19850"
DENNIS_CDP = "20100"
DEPEW_TOWN = "20300"
DEVOL_TOWN = "20450"
DEWAR_TOWN = "20500"
DEWEY_CITY = "20550"
DIBBLE_TOWN = "20650"
DICKSON_TOWN = "20700"
DILL_CITY_TOWN = "20850"
DISNEY_TOWN = "20900"
DIXON_CDP = "21000"
DODGE_CDP = "21020"
DOTYVILLE_CDP = "21150"
DOUGHERTY_TOWN = "21200"
DOUGLAS_TOWN = "21250"
DOVER_TOWN = "21350"
DRIPPING_SPRINGS_CDP = "21672"
DROWNING_CREEK_CDP = "21676"
DRUMMOND_TOWN = "21700"
DRUMRIGHT_CITY = "21750"
DRY_CREEK_CDP = "21755"
DUCHESS_LANDING_CDP = "21760"
DUNCAN_CITY = "21900"
DURANT_CITY = "22050"
DURHAM_CDP = "22100"
DUSTIN_TOWN = "22200"
DWIGHT_MISSION_CDP = "22275"
EAGLE_CITY_CDP = "22300"
EAGLETOWN_CDP = "22350"
EAKLY_TOWN = "22400"
EARL_CDP = "22450"
EARLSBORO_TOWN = "22500"
EAST_DUKE_TOWN = "22550"
EDGEWATER_PARK_CDP = "23100"
EDMOND_CITY = "23200"
EL_RENO_CITY = "23700"
ELDON_CDP = "23300"
ELDORADO_TOWN = "23350"
ELGIN_CITY = "23450"
ELK_CITY_CITY = "23500"
ELM_GROVE_CDP = "23575"
ELMER_TOWN = "23550"
ELMORE_CITY_TOWN = "23600"
ELOHIM_CITY_CDP = "23675"
EMET_CDP = "23850"
EMPIRE_CITY_TOWN = "23900"
ENID_CITY = "23950"
ENTERPRISE_CDP = "24050"
ERICK_CITY = "24200"
ERIN_SPRINGS_TOWN = "24300"
ETOWAH_TOWN = "24460"
ETTA_CDP = "24500"
EUFAULA_CITY = "24650"
EVENING_SHADE_CDP = "24762"
FAIR_OAKS_TOWN = "25000"
FAIRFAX_TOWN = "24850"
FAIRFIELD_CDP = "24875"
FAIRLAND_TOWN = "24900"
FAIRMONT_TOWN = "24950"
FAIRVIEW_CITY = "25100"
FALLIS_TOWN = "25250"
FANSHAWE_TOWN = "25400"
FARGO_TOWN = "25450"
FAXON_TOWN = "25650"
FAY_CDP = "25700"
FELT_CDP = "25850"
FINLEY_CDP = "26000"
FITTSTOWN_CDP = "26200"
FITZHUGH_TOWN = "26250"
FLETCHER_TOWN = "26350"
FLINT_CREEK_CDP = "26415"
FLUTE_SPRINGS_CDP = "26525"
FORAKER_TOWN = "26750"
FOREST_PARK_TOWN = "26850"
FORGAN_TOWN = "26900"
FORT_COBB_TOWN = "27100"
FORT_COFFEE_TOWN = "27150"
FORT_GIBSON_TOWN = "27200"
FORT_SUPPLY_TOWN = "27350"
FORT_TOWSON_TOWN = "27400"
FOSS_TOWN = "27450"
FOSTER_TOWN = "27500"
FOX_CDP = "27550"
FOYIL_TOWN = "27600"
FRANCIS_TOWN = "27650"
FREDERICK_CITY = "27800"
FREEDOM_TOWN = "27850"
FRIENDSHIP_TOWN = "27900"
GAGE_TOWN = "28250"
GANS_TOWN = "28350"
GARBER_CITY = "28500"
GARVIN_TOWN = "28700"
GATE_TOWN = "28800"
GEARY_CITY = "28900"
GENE_AUTRY_TOWN = "28950"
GERONIMO_TOWN = "29100"
GERTY_TOWN = "29150"
GIDEON_CDP = "29300"
GLENCOE_TOWN = "29400"
GLENPOOL_CITY = "29600"
GOLDEN_CDP = "29800"
GOLDSBY_TOWN = "29850"
GOLTRY_TOWN = "29900"
GOODWELL_TOWN = "30200"
GORE_TOWN = "30300"
GOTEBO_TOWN = "30350"
GOULD_TOWN = "30400"
GOWEN_CDP = "30500"
GRACEMONT_TOWN = "30600"
GRAINOLA_TOWN = "30750"
GRAND_LAKE_TOWNE_TOWN = "30900"
GRANDFIELD_CITY = "30850"
GRANDVIEW_CDP = "30915"
GRANITE_TOWN = "30950"
GRANT_CDP = "31000"
GRAYSON_TOWN = "31150"
GREASY_CDP = "31165"
GREENFIELD_TOWN = "31250"
GREENVILLE_CDP = "31375"
GREGORY_CDP = "31425"
GROVE_CITY = "31600"
GUTHRIE_CITY = "31700"
GUYMON_CITY = "31750"
HAILEYVILLE_CITY = "31900"
HALLETT_TOWN = "32050"
HAMMON_TOWN = "32250"
HANNA_TOWN = "32350"
HANSON_CDP = "32400"
HARDESTY_TOWN = "32550"
HARRAH_CITY = "32750"
HARTSHORNE_CITY = "32850"
HASKELL_TOWN = "32900"
HASTINGS_TOWN = "33000"
HAWORTH_TOWN = "33150"
HAYWOOD_CDP = "33250"
HEADRICK_TOWN = "33300"
HEALDTON_CITY = "33350"
HEAVENER_CITY = "33400"
HELENA_TOWN = "33450"
HENDRIX_TOWN = "33600"
HENNEPIN_CDP = "33650"
HENNESSEY_TOWN = "33700"
HENRYETTA_CITY = "33750"
HICKORY_TOWN = "34150"
HILLSDALE_TOWN = "34650"
HINTON_TOWN = "34750"
HITCHCOCK_TOWN = "34850"
HITCHITA_TOWN = "34900"
HOBART_CITY = "35000"
HOCHATOWN_CDP = "35030"
HODGEN_CDP = "35150"
HOFFMAN_TOWN = "35300"
HOLDENVILLE_CITY = "35400"
HOLLIS_CITY = "35500"
HOLLISTER_TOWN = "35550"
HOMESTEAD_CDP = "35800"
HOMINY_CITY = "35850"
HONEY_HILL_CDP = "35875"
HOOKER_CITY = "36000"
HOOT_OWL_TOWN = "36020"
HOPETON_CDP = "36050"
HORNTOWN_TOWN = "36090"
HOUGH_CDP = "36115"
HOWE_TOWN = "36150"
HOYT_CDP = "36200"
HUGO_CITY = "36300"
HULBERT_TOWN = "36400"
HUNTER_TOWN = "36600"
HYDRO_TOWN = "36700"
IXL_TOWN = "37410"
IDABEL_CITY = "36750"
INDIAHOMA_TOWN = "36850"
INDIANOLA_CDP = "36945"
INDIANOLA_TOWN = "36950"
INGALLS_CDP = "37000"
INOLA_TOWN = "37100"
IRON_POST_CDP = "37275"
ISABELLA_CDP = "37350"
JAY_CITY = "37650"
JEFFERSON_TOWN = "37750"
JENKS_CITY = "37800"
JENNINGS_TOWN = "37850"
JET_TOWN = "38000"
JOHNSON_PRAIRIE_CDP = "38201"
JOHNSON_TOWN = "38200"
JONES_TOWN = "38350"
JUSTICE_CDP = "38475"
KANSAS_TOWN = "38600"
KATIE_TOWN = "38700"
KAW_CITY_CITY = "38800"
KEEFTON_CDP = "38850"
KELLYVILLE_TOWN = "39000"
KEMP_TOWN = "39050"
KENDRICK_TOWN = "39150"
KENEFIC_TOWN = "39200"
KENTON_CDP = "39400"
KENWOOD_CDP = "39450"
KEOTA_TOWN = "39500"
KETCHUM_TOWN = "39550"
KEYES_TOWN = "39600"
KEYS_CDP = "39625"
KIEFER_TOWN = "39750"
KILDARE_TOWN = "39800"
KINGFISHER_CITY = "39850"
KINGSTON_TOWN = "39900"
KINTA_TOWN = "39950"
KIOWA_TOWN = "40000"
KNOWLES_TOWN = "40100"
KONAWA_CITY = "40200"
KREBS_CITY = "40300"
KREMLIN_TOWN = "40400"
LAHOMA_TOWN = "40700"
LAKE_ALUMA_TOWN = "40800"
LAKE_ELLSWORTH_ADDITION_CDP = "40875"
LAKESIDE_VILLAGE_CDP = "41050"
LAMAR_TOWN = "41250"
LAMBERT_TOWN = "41300"
LAMONT_TOWN = "41350"
LANE_CDP = "41400"
LANGLEY_TOWN = "41500"
LANGSTON_TOWN = "41550"
LATTA_CDP = "41680"
LAVERNE_TOWN = "41700"
LAWRENCE_CREEK_TOWN = "41760"
LAWTON_CITY = "41850"
LAWTONKA_ACRES_CDP = "41856"
LE_FLORE_TOWN = "42150"
LEACH_CDP = "41900"
LEBANON_CDP = "41950"
LEEDEY_TOWN = "42050"
LEHIGH_CITY = "42200"
LENAPAH_TOWN = "42300"
LEON_TOWN = "42450"
LEONARD_CDP = "42500"
LEQUIRE_CDP = "42600"
LEXINGTON_CITY = "42700"
LIBERTY_CDP = "42850"
LIBERTY_TOWN = "42860"
LIMA_TOWN = "43000"
LIMESTONE_CDP = "43057"
LINDSAY_CITY = "43150"
LITTLE_CITY_CDP = "43400"
LITTLE_PONDEROSA_CDP = "43425"
LITTLE_ROCK_CDP = "43442"
LOCO_TOWN = "43450"
LOCUST_GROVE_TOWN = "43500"
LONE_CHIMNEY_TOWN = "43725"
LONE_GROVE_CITY = "43750"
LONE_WOLF_TOWN = "43850"
LONG_CDP = "43900"
LONGDALE_TOWN = "43950"
LONGTOWN_CDP = "43975"
LOOKEBA_TOWN = "44000"
LOST_CITY_CDP = "44075"
LOTSEE_TOWN = "44100"
LOVELAND_TOWN = "44150"
LOVELL_CDP = "44200"
LOWREY_CDP = "44275"
LOYAL_TOWN = "44300"
LUCIEN_CDP = "44350"
LUTHER_TOWN = "44500"
LYONS_SWITCH_CDP = "44775"
MACOMB_TOWN = "45500"
MADILL_CITY = "45750"
MALLARD_BAY_CDP = "45930"
MANCHESTER_TOWN = "46000"
MANGUM_CITY = "46050"
MANITOU_TOWN = "46150"
MANNFORD_TOWN = "46200"
MANNSVILLE_TOWN = "46300"
MARAMEC_TOWN = "46400"
MARBLE_CITY_TOWN = "46450"
MARIETTA_CDP = "46488"
MARIETTA_CITY = "46500"
MARLAND_TOWN = "46550"
MARLOW_CITY = "46600"
MARSHALL_TOWN = "46650"
MARTHA_TOWN = "46700"
MAUD_CITY = "46900"
MAY_TOWN = "47000"
MAYSVILLE_TOWN = "47150"
MAZIE_CDP = "47200"
MCALESTER_CITY = "44800"
MCBRIDE_CDP = "44900"
MCCORD_CDP = "44925"
MCCURTAIN_TOWN = "44950"
MCLOUD_CITY = "45350"
MEAD_TOWN = "47250"
MEDFORD_CITY = "47300"
MEDICINE_PARK_TOWN = "47350"
MEEKER_TOWN = "47450"
MEHAN_CDP = "47550"
MENO_TOWN = "47750"
MERIDIAN_TOWN = "47800"
MIAMI_CITY = "48000"
MIDDLEBERG_CDP = "48100"
MIDWEST_CITY_CITY = "48350"
MILBURN_TOWN = "48400"
MILFAY_CDP = "48450"
MILL_CREEK_TOWN = "48500"
MILLERTON_TOWN = "48600"
MINCO_CITY = "48750"
MOFFETT_TOWN = "49000"
MONROE_CDP = "49050"
MOODYS_CDP = "49100"
MOORE_CITY = "49200"
MOORELAND_TOWN = "49250"
MORRIS_CITY = "49400"
MORRISON_TOWN = "49450"
MOUNDS_TOWN = "49550"
MOUNTAIN_PARK_TOWN = "49600"
MOUNTAIN_VIEW_TOWN = "49650"
MOYERS_CDP = "49750"
MULBERRY_CDP = "49825"
MULDROW_TOWN = "49850"
MULE_BARN_TOWN = "49860"
MULHALL_TOWN = "49900"
MURPHY_CDP = "49950"
MUSKOGEE_CITY = "50050"
MUSTANG_CITY = "50100"
MUTUAL_TOWN = "50150"
NARCISSA_CDP = "50200"
NARDIN_CDP = "50250"
NASH_TOWN = "50300"
NASHOBA_CDP = "50350"
NELAGONEY_CDP = "50800"
NESCATUNGA_CDP = "50975"
NEW_ALLUWE_TOWN = "51050"
NEW_CORDELL_CITY = "51250"
NEW_EUCHA_CDP = "51275"
NEW_WOODVILLE_TOWN = "51750"
NEWCASTLE_CITY = "51150"
NEWKIRK_CITY = "51300"
NICHOLS_HILLS_CITY = "51800"
NICOMA_PARK_CITY = "51850"
NICUT_CDP = "51900"
NINNEKAH_TOWN = "52100"
NOBLE_CITY = "52150"
NORGE_TOWN = "52450"
NORMAN_CITY = "52500"
NORTH_ENID_TOWN = "52600"
NORTH_MIAMI_TOWN = "52700"
NORWOOD_CDP = "52859"
NOTCHIETOWN_CDP = "52862"
NOWATA_CITY = "52900"
OAK_GROVE_TOWN = "53210"
OAK_HILL_PINEY_CDP = "53301"
OAKHURST_CDP = "53350"
OAKLAND_TOWN = "53400"
OAKS_TOWN = "53550"
OAKWOOD_TOWN = "53600"
OCHELATA_TOWN = "53700"
OILTON_CITY = "54000"
OKARCHE_TOWN = "54050"
OKAY_TOWN = "54100"
OKEENE_TOWN = "54150"
OKEMAH_CITY = "54200"
OKLAHOMA_CITY_CITY = "55000"
OKMULGEE_CITY = "55150"
OKTAHA_TOWN = "55200"
OLD_EUCHA_CDP = "55275"
OLD_GREEN_CDP = "55285"
OLIVE_CDP = "55350"
OLUSTEE_TOWN = "55450"
OOLOGAH_TOWN = "55750"
OPTIMA_TOWN = "55850"
ORLANDO_TOWN = "56050"
OSAGE_TOWN = "56150"
OWASSO_CITY = "56650"
PADEN_TOWN = "56800"
PANAMA_TOWN = "56900"
PANOLA_CDP = "56950"
PAOLI_TOWN = "57100"
PARADISE_HILL_TOWN = "57150"
PARK_HILL_CDP = "57300"
PAULS_VALLEY_CITY = "57550"
PAWHUSKA_CITY = "57600"
PAWNEE_CITY = "57650"
PEAVINE_CDP = "57875"
PECKHAM_CDP = "57900"
PEGGS_CDP = "57950"
PENSACOLA_TOWN = "58050"
PEORIA_TOWN = "58100"
PERKINS_CITY = "58150"
PERRY_CITY = "58250"
PERSHING_CDP = "58300"
PETTIT_CDP = "58400"
PHILLIPS_TOWN = "58500"
PICKETT_CDP = "58650"
PIEDMONT_CITY = "58700"
PIN_OAK_ACRES_CDP = "59175"
PINEY_CDP = "59100"
PINHOOK_CORNER_CDP = "59125"
PINK_TOWN = "59150"
PITTSBURG_TOWN = "59350"
PLATTER_CDP = "59500"
POCASSET_TOWN = "59700"
POCOLA_TOWN = "59750"
PONCA_CITY_CITY = "59850"
POND_CREEK_CITY = "59950"
PONTOTOC_CDP = "60000"
PORTER_TOWN = "60150"
PORUM_TOWN = "60250"
POTEAU_CITY = "60350"
PRAGUE_CITY = "60500"
PRESTON_CDP = "60650"
PROCTOR_CDP = "60750"
PRUE_TOWN = "60850"
PRYOR_CREEK_CITY = "61000"
PUMP_BACK_CDP = "61020"
PUMPKIN_HOLLOW_CDP = "61113"
PURCELL_CITY = "61150"
PUTNAM_TOWN = "61250"
QUAPAW_TOWN = "61400"
QUAY_CDP = "61450"
QUINLAN_CDP = "61500"
QUINTON_TOWN = "61550"
RALSTON_TOWN = "61650"
RAMONA_TOWN = "61700"
RANDLETT_TOWN = "61850"
RATLIFF_CITY_TOWN = "61900"
RATTAN_TOWN = "61950"
RAVIA_TOWN = "62000"
REAGAN_CDP = "62100"
RED_OAK_TOWN = "62550"
RED_ROCK_TOWN = "62650"
REDBIRD_SMITH_CDP = "62275"
REDBIRD_TOWN = "62200"
REMY_CDP = "62875"
RENFROW_TOWN = "62900"
RENTIESVILLE_TOWN = "62950"
REYDON_TOWN = "63100"
RINGLING_TOWN = "63350"
RINGWOOD_TOWN = "63450"
RIPLEY_TOWN = "63500"
RIVER_BOTTOM_CDP = "63537"
ROCK_ISLAND_TOWN = "63600"
ROCKY_FORD_CDP = "63715"
ROCKY_MOUNTAIN_CDP = "63720"
ROCKY_POINT_CDP = "63730"
ROCKY_TOWN = "63700"
ROFF_TOWN = "63750"
ROLAND_TOWN = "63800"
ROOSEVELT_TOWN = "63900"
ROSE_CDP = "63950"
ROSEDALE_TOWN = "64000"
ROSSTON_TOWN = "64050"
RUSH_SPRINGS_TOWN = "64300"
RYAN_TOWN = "64600"
SALINA_TOWN = "64950"
SALLISAW_CITY = "65000"
SAMS_CORNER_CDP = "65062"
SAND_HILL_CDP = "65240"
SAND_POINT_CDP = "65250"
SAND_SPRINGS_CITY = "65300"
SAPULPA_CITY = "65400"
SASAKWA_TOWN = "65500"
SAVANNA_TOWN = "65600"
SAWYER_TOWN = "65650"
SAYRE_CITY = "65700"
SCHULTER_TOWN = "65900"
SCIPIO_CDP = "65950"
SEILING_CITY = "66250"
SELMAN_CDP = "66300"
SEMINOLE_CITY = "66350"
SENTINEL_TOWN = "66400"
SEQUOYAH_CDP = "66450"
SEWARD_CDP = "66500"
SHADY_GROVE_CDP_CHEROKEE_COUNTY = "66510"
SHADY_GROVE_CDP_MCINTOSH_COUNTY = "66520"
SHADY_POINT_TOWN = "66550"
SHAMROCK_TOWN = "66600"
SHARON_TOWN = "66650"
SHATTUCK_TOWN = "66750"
SHAWNEE_CITY = "66800"
SHIDLER_CITY = "67200"
SHORT_CDP = "67400"
SILO_TOWN = "67550"
SIMMS_CDP = "67625"
SKEDEE_TOWN = "67800"
SKIATOOK_CITY = "67850"
SLAUGHTERVILLE_TOWN = "67950"
SLICK_TOWN = "68000"
SMITH_VILLAGE_TOWN = "68200"
SMITHVILLE_TOWN = "68250"
SNAKE_CREEK_CDP = "68275"
SNYDER_CITY = "68400"
SOPER_TOWN = "68500"
SOUR_JOHN_CDP = "68537"
SOUTH_COFFEYVILLE_TOWN = "68600"
SPARKS_TOWN = "68950"
SPARROWHAWK_CDP = "68951"
SPAULDING_TOWN = "69000"
SPAVINAW_TOWN = "69050"
SPENCER_CITY = "69200"
SPERRY_TOWN = "69300"
SPIRO_TOWN = "69350"
SPORTMANS_SHORES_CDP = "69392"
SPORTSMEN_ACRES_TOWN = "69400"
SPRINGER_TOWN = "69500"
ST_LOUIS_TOWN = "64850"
STEELY_HOLLOW_CDP = "70037"
STERLING_TOWN = "70150"
STIDHAM_TOWN = "70200"
STIGLER_CITY = "70250"
STILLWATER_CITY = "70300"
STILWELL_CITY = "70350"
STONEWALL_TOWN = "70500"
STONEY_POINT_CDP = "70512"
STRANG_TOWN = "70750"
STRATFORD_TOWN = "70800"
STRINGTOWN_TOWN = "70850"
STRONG_CITY_TOWN = "70950"
STROUD_CITY = "71000"
STUART_TOWN = "71050"
SUGDEN_TOWN = "71250"
SULPHUR_CITY = "71350"
SUMMIT_TOWN = "71450"
SUMNER_CDP = "71500"
SUNRAY_CDP = "71650"
SWEETWATER_TOWN = "71900"
SWINK_CDP = "71950"
SYCAMORE_CDP = "71965"
TAFT_TOWN = "72050"
TAGG_FLATS_CDP = "72075"
TAHLEQUAH_CITY = "72100"
TALALA_TOWN = "72200"
TALIHINA_TOWN = "72250"
TALOGA_TOWN = "72350"
TAMAHA_TOWN = "72400"
TATUMS_TOWN = "72500"
TAYLOR_FERRY_CDP = "72610"
TECUMSEH_CITY = "72650"
TEMPLE_TOWN = "72750"
TENKILLER_CDP = "72775"
TERESITA_CDP = "72800"
TERLTON_TOWN = "72850"
TERRAL_TOWN = "72900"
TEXANNA_CDP = "72950"
TEXHOMA_TOWN = "73100"
TEXOLA_TOWN = "73150"
THACKERVILLE_TOWN = "73200"
THE_VILLAGE_CITY = "73250"
THOMAS_CITY = "73450"
TIAWAH_CDP = "73600"
TIPTON_TOWN = "73850"
TISHOMINGO_CITY = "73900"
TITANIC_CDP = "73950"
TONKAWA_TRIBAL_HOUSING_CDP = "74159"
TONKAWA_CITY = "74150"
TOPPERS_CDP = "74180"
TRIBBEY_TOWN = "74400"
TRYON_TOWN = "74550"
TULLAHASSEE_TOWN = "74650"
TULSA_CITY = "75000"
TUPELO_CITY = "75050"
TURLEY_CDP = "75150"
TURPIN_CDP = "75200"
TUSHKA_TOWN = "75250"
TUSKAHOMA_CDP = "75300"
TUTTLE_CITY = "75450"
TWIN_LAKES_CDP = "75575"
TWIN_OAKS_CDP = "75600"
TYRONE_TOWN = "75750"
UNION_CITY_TOWN = "75950"
UTICA_CDP = "76350"
VALLEY_BROOK_TOWN = "76500"
VALLEY_PARK_TOWN = "76600"
VALLIANT_TOWN = "76650"
VANOSS_CDP = "76850"
VELMA_TOWN = "76900"
VERA_TOWN = "76950"
VERDEN_TOWN = "77000"
VERDIGRIS_TOWN = "77050"
VIAN_TOWN = "77250"
VICI_TOWN = "77300"
VINITA_CITY = "77550"
WAGONER_CITY = "77850"
WAINWRIGHT_TOWN = "77900"
WAKITA_TOWN = "77950"
WALTERS_CITY = "78150"
WANETTE_TOWN = "78200"
WANN_TOWN = "78250"
WAPANUCKA_TOWN = "78300"
WARDVILLE_CDP = "78350"
WARNER_TOWN = "78400"
WARR_ACRES_CITY = "78500"
WARWICK_TOWN = "78650"
WASHINGTON_TOWN = "78700"
WASHITA_CDP = "78750"
WATONGA_CITY = "78950"
WATOVA_CDP = "79000"
WATTS_TOWN = "79100"
WAUHILLAU_CDP = "79150"
WAUKOMIS_TOWN = "79200"
WAURIKA_CITY = "79250"
WAYNE_TOWN = "79300"
WAYNOKA_CITY = "79350"
WEATHERFORD_CITY = "79450"
WEBB_CITY_TOWN = "79600"
WEBBERS_FALLS_TOWN = "79650"
WELCH_TOWN = "79750"
WELEETKA_TOWN = "79800"
WELLING_CDP = "79850"
WELLSTON_TOWN = "79900"
WELTY_CDP = "80000"
WEST_PEAVINE_CDP = "80230"
WEST_SILOAM_SPRINGS_TOWN = "80350"
WESTPORT_TOWN = "80250"
WESTVILLE_TOWN = "80450"
WETUMKA_CITY = "80500"
WEWOKA_CITY = "80550"
WHIPPOORWILL_CDP = "80675"
WHITE_EAGLE_CDP = "80750"
WHITE_OAK_CDP = "80850"
WHITE_WATER_CDP = "80912"
WHITEFIELD_TOWN = "80800"
WHITEHORN_COVE_CDP = "80813"
WHITESBORO_CDP = "80900"
WICKLIFFE_CDP = "80975"
WILBURTON_CITY = "81000"
WILLOW_TOWN = "81300"
WILSON_CITY = "81500"
WINCHESTER_TOWN = "81575"
WISTER_TOWN = "81750"
WOODALL_CDP = "81912"
WOODLAWN_PARK_TOWN = "82000"
WOODWARD_CITY = "82150"
WRIGHT_CITY_TOWN = "82200"
WYANDOTTE_TOWN = "82250"
WYNNEWOOD_CITY = "82400"
WYNONA_TOWN = "82450"
YALE_CITY = "82500"
YEAGER_TOWN = "82650"
YUKON_CITY = "82950"
ZEB_CDP = "83030"
ZENA_CDP = "83050"
ZION_CDP = "83125"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Missouri."""


ADRIAN_CITY = "00244"
ADVANCE_CITY = "00262"
AFFTON_CDP = "00280"
AGENCY_VILLAGE = "00298"
AIRPORT_DRIVE_VILLAGE = "00424"
ALBA_CITY = "00496"
ALBANY_CITY = "00514"
ALDRICH_VILLAGE = "00568"
ALEXANDRIA_CITY = "00604"
ALLENDALE_VILLAGE = "00712"
ALLENVILLE_VILLAGE = "00748"
ALMA_CITY = "00802"
ALTAMONT_VILLAGE = "00910"
ALTENBURG_CITY = "00928"
ALTON_CITY = "00964"
AMAZONIA_VILLAGE = "01018"
AMITY_TOWN = "01054"
AMORET_CITY = "01072"
AMSTERDAM_CITY = "01090"
ANDERSON_CITY = "01198"
ANNADA_VILLAGE = "01252"
ANNAPOLIS_CITY = "01270"
ANNISTON_TOWN = "01288"
APPLETON_CITY_CITY = "01522"
ARBELA_TOWN = "01576"
ARBYRD_CITY = "01630"
ARCADIA_CITY = "01648"
ARCHIE_CITY = "01702"
ARCOLA_VILLAGE = "01720"
ARGYLE_TOWN = "01828"
ARKOE_TOWN = "01864"
ARMSTRONG_CITY = "01954"
ARNOLD_CITY = "01972"
ARROW_POINT_VILLAGE = "02034"
ARROW_ROCK_TOWN = "02044"
ASBURY_CITY = "02098"
ASH_GROVE_CITY = "02188"
ASHBURN_TOWN = "02152"
ASHLAND_CITY = "02242"
ASHLEY_CDP = "02260"
ATLANTA_CITY = "02422"
AUGUSTA_TOWN = "02512"
AULLVILLE_VILLAGE = "02530"
AURORA_SPRINGS_CDP = "02584"
AURORA_CITY = "02548"
AUXVASSE_CITY = "02638"
AVA_CITY = "02674"
AVALON_CDP = "02692"
AVILLA_TOWN = "02746"
AVONDALE_CITY = "02800"
BAGNELL_TOWN = "02962"
BAKER_VILLAGE = "03034"
BAKERSFIELD_VILLAGE = "03052"
BALDWIN_PARK_VILLAGE = "03124"
BALLWIN_CITY = "03160"
BARING_CITY = "03322"
BARNARD_CITY = "03340"
BARNETT_CITY = "03376"
BARNHART_CDP = "03394"
BATES_CITY_CITY = "03556"
BATTLEFIELD_CITY = "03592"
BEL_NOR_VILLAGE = "04348"
BEL_RIDGE_VILLAGE = "04366"
BELL_CITY_CITY = "04132"
BELLA_VILLA_CITY = "04114"
BELLE_CITY = "04150"
BELLEFONTAINE_NEIGHBORS_CITY = "04222"
BELLERIVE_ACRES_CITY = "04248"
BELLFLOWER_CITY = "04330"
BELTON_CITY = "04384"
BENNETT_SPRINGS_CDP = "04525"
BENT_TREE_HARBOR_CDP = "04864"
BENTON_CITY_VILLAGE = "04834"
BENTON_CITY = "04798"
BERGER_CITY = "04888"
BERKELEY_CITY = "04906"
BERNIE_CITY = "04960"
BERTRAND_CITY = "04996"
BETHANY_CITY = "05068"
BETHEL_VILLAGE = "05104"
BEVERLY_HILLS_CITY = "05248"
BEVIER_CITY = "05266"
BIEHLE_CDP = "05320"
BIG_LAKE_VILLAGE = "05495"
BIG_SPRING_CDP = "05608"
BIGELOW_VILLAGE = "05464"
BILLINGS_CITY = "05626"
BIRCH_TREE_CITY = "05734"
BIRMINGHAM_VILLAGE = "05824"
BISMARCK_CITY = "05878"
BLACK_JACK_CITY = "06004"
BLACKBURN_CITY = "05950"
BLACKWATER_CITY = "06148"
BLAIRSTOWN_CITY = "06238"
BLANCHARD_CDP = "06247"
BLAND_CITY = "06256"
BLODGETT_VILLAGE = "06346"
BLOOMFIELD_CITY = "06382"
BLOOMSDALE_CITY = "06454"
BLUE_EYE_TOWN = "06526"
BLUE_SPRINGS_CITY = "06652"
BLUE_SUMMIT_CDP = "06670"
BLYTHEDALE_VILLAGE = "06742"
BOGARD_CITY = "06832"
BOLCKOW_CITY = "06922"
BOLIVAR_CITY = "06976"
BONNE_TERRE_CITY = "07102"
BOONVILLE_CITY = "07318"
BOSWORTH_CITY = "07426"
BOURBON_CITY = "07534"
BOWLING_GREEN_CITY = "07660"
BRAGG_CITY_TOWN = "07876"
BRANDSVILLE_CITY = "07948"
BRANSON_WEST_CITY = "07989"
BRANSON_CITY = "07966"
BRASHEAR_CITY = "08002"
BRAYMER_CITY = "08038"
BRECKENRIDGE_HILLS_CITY = "08164"
BRECKENRIDGE_CITY = "08128"
BRENTWOOD_CITY = "08236"
BREWER_CDP = "08272"
BRIARWOOD_ESTATES_CDP = "08294"
BRIDGETON_CITY = "08398"
BRIMSON_VILLAGE = "08470"
BRONAUGH_CITY = "08614"
BROOKFIELD_CITY = "08650"
BROOKLYN_HEIGHTS_TOWN = "08776"
BROSELEY_CDP = "08812"
BROWNING_CITY = "08884"
BROWNINGTON_TOWN = "08902"
BRUMLEY_TOWN = "08974"
BRUNSWICK_CITY = "09046"
BUCKLIN_CITY = "09388"
BUCKNER_CITY = "09424"
BUELL_CDP = "09496"
BUFFALO_CITY = "09514"
BULL_CREEK_VILLAGE = "09642"
BUNCETON_CITY = "09658"
BUNKER_CITY = "09694"
BURFORDVILLE_CDP = "09784"
BURGESS_CDP = "09802"
BURLINGTON_JUNCTION_CITY = "09838"
BUTLER_CITY = "10054"
BUTTERFIELD_CITY = "10144"
BYRNES_MILL_CITY = "10240"
CABOOL_CITY = "10288"
CAINSVILLE_CITY = "10342"
CAIRO_VILLAGE = "10360"
CALEDONIA_VILLAGE = "10432"
CALHOUN_CITY = "10450"
CALIFORNIA_CITY = "10468"
CALLAO_CITY = "10486"
CALVERTON_PARK_CITY = "10612"
CAMDEN_POINT_CITY = "10792"
CAMDEN_CITY = "10738"
CAMDENTON_CITY = "10810"
CAMERON_CITY = "10828"
CAMPBELL_CITY = "10864"
CANALOU_CITY = "11026"
CANTON_CITY = "11134"
CAPE_GIRARDEAU_CITY = "11242"
CARDWELL_CITY = "11350"
CARL_JUNCTION_CITY = "11368"
CARROLLTON_CITY = "11566"
CARTERVILLE_CITY = "11638"
CARTHAGE_CITY = "11656"
CARUTHERSVILLE_CITY = "11692"
CARYTOWN_CITY = "11728"
CASSVILLE_CITY = "11890"
CASTLE_POINT_CDP = "11908"
CATRON_TOWN = "12052"
CAVE_TOWN = "12079"
CEDAR_HILL_CDP = "12358"
CEDAR_HILL_LAKES_VILLAGE = "12376"
CENTER_CITY = "12592"
CENTERTOWN_TOWN = "12664"
CENTERVIEW_CITY = "12682"
CENTERVILLE_CITY = "12718"
CENTRALIA_CITY = "12898"
CHAFFEE_CITY = "12988"
CHAIN_OF_ROCKS_VILLAGE = "13006"
CHAIN_O_LAKES_VILLAGE = "13015"
CHAMOIS_CITY = "13060"
CHAMP_VILLAGE = "13078"
CHARLACK_CITY = "13330"
CHARLESTON_CITY = "13366"
CHARMWOOD_TOWN = "13390"
CHEROKEE_PASS_CDP = "13474"
CHESAPEAKE_CDP = "13582"
CHESTERFIELD_CITY = "13600"
CHILHOWEE_TOWN = "13654"
CHILLICOTHE_CITY = "13690"
CHULA_CITY = "13852"
CLARENCE_CITY = "13978"
CLARK_CITY = "14068"
CLARKSBURG_CITY = "14140"
CLARKSDALE_CITY = "14158"
CLARKSON_VALLEY_CITY = "14176"
CLARKSVILLE_CITY = "14194"
CLARKTON_CITY = "14212"
CLAYCOMO_VILLAGE = "14554"
CLAYTON_CITY = "14572"
CLEARMONT_CITY = "14662"
CLEVELAND_CITY = "14770"
CLEVER_CITY = "14788"
CLIFF_VILLAGE_VILLAGE = "14806"
CLIFTON_HILL_CITY = "14896"
CLIMAX_SPRINGS_CDP = "14914"
CLINTON_CITY = "14986"
CLYDE_VILLAGE = "15130"
COBALT_VILLAGE = "15220"
COFFEY_CITY = "15274"
COLE_CAMP_CITY = "15436"
COLLINS_VILLAGE = "15562"
COLUMBIA_CITY = "15670"
COMMERCE_VILLAGE = "15760"
CONCEPTION_CDP = "15886"
CONCEPTION_JUNCTION_TOWN = "15922"
CONCORD_CDP = "16030"
CONCORDIA_CITY = "16102"
CONEY_ISLAND_VILLAGE = "16115"
CONNELSVILLE_CDP = "16138"
CONWAY_CITY = "16192"
COOL_VALLEY_CITY = "16228"
COOTER_CITY = "16336"
CORDER_CITY = "16408"
CORNING_TOWN = "16462"
COSBY_VILLAGE = "16588"
COTTLEVILLE_CITY = "16678"
COUNTRY_CLUB_HILLS_CITY = "16822"
COUNTRY_CLUB_VILLAGE = "16802"
COUNTRY_LIFE_ACRES_VILLAGE = "16876"
COWGILL_CITY = "16984"
CRAIG_CITY = "17056"
CRANE_CITY = "17074"
CREIGHTON_CITY = "17164"
CRESTWOOD_CITY = "17218"
CREVE_COEUR_CITY = "17272"
CROCKER_CITY = "17344"
CROSS_TIMBERS_CITY = "17524"
CRYSTAL_CITY_CITY = "17632"
CRYSTAL_LAKE_PARK_CITY = "17650"
CRYSTAL_LAKES_CITY = "17660"
CUBA_CITY = "17668"
CURRYVILLE_CITY = "17902"
DADEVILLE_VILLAGE = "17992"
DALTON_TOWN = "18118"
DANVILLE_CDP = "18190"
DARDENNE_PRAIRIE_CITY = "18253"
DARLINGTON_VILLAGE = "18316"
DAWN_CDP = "18496"
DE_KALB_TOWN = "18946"
DE_SOTO_CITY = "19252"
DE_WITT_CITY = "19378"
DEARBORN_CITY = "18658"
DEEPWATER_CITY = "18730"
DEERFIELD_VILLAGE = "18802"
DEERING_CDP = "18838"
DEFIANCE_CDP = "18910"
DELLWOOD_CITY = "19018"
DELTA_CITY = "19072"
DENNIS_ACRES_VILLAGE = "19090"
DENTON_CDP = "19144"
DENVER_VILLAGE = "19162"
DES_ARC_VILLAGE = "19198"
DES_PERES_CITY = "19270"
DESLOGE_CITY = "19216"
DEXTER_CITY = "19396"
DIAMOND_TOWN = "19432"
DIEHLSTADT_VILLAGE = "19486"
DIGGINS_VILLAGE = "19504"
DIXON_CITY = "19630"
DOE_RUN_CDP = "19684"
DONIPHAN_CITY = "19792"
DOOLITTLE_CITY = "19828"
DOVER_TOWN = "19918"
DOWNING_CITY = "19990"
DREXEL_CITY = "20134"
DUDLEY_CITY = "20296"
DUENWEG_CITY = "20314"
DUQUESNE_VILLAGE = "20512"
DUTCHTOWN_CDP = "20566"
EAGLE_ROCK_CDP = "20656"
EAGLEVILLE_TOWN = "20674"
EAST_LYNNE_CITY = "20980"
EAST_PRAIRIE_CITY = "21052"
EASTON_CITY = "21034"
EDGAR_SPRINGS_CITY = "21214"
EDGERTON_CITY = "21250"
EDINA_CITY = "21322"
EDINBURG_CDP = "21340"
EDMUNDSON_CITY = "21376"
EL_DORADO_SPRINGS_CITY = "21502"
ELDON_CITY = "21484"
ELLINGTON_CITY = "21844"
ELLISVILLE_CITY = "21898"
ELLSINORE_CITY = "21916"
ELMER_CITY = "21988"
ELMIRA_VILLAGE = "22006"
ELMO_CITY = "22024"
ELSBERRY_CITY = "22114"
EMERALD_BEACH_VILLAGE = "22250"
EMINENCE_CITY = "22276"
EMMA_CITY = "22312"
EOLIA_VILLAGE = "22474"
ESSEX_CITY = "22600"
ETHEL_TOWN = "22672"
EUGENE_CDP = "22798"
EUREKA_CITY = "22834"
EVERGREEN_VILLAGE = "22951"
EVERTON_CITY = "22996"
EWING_CITY = "23032"
EXCELLO_CDP = "23050"
EXCELSIOR_ESTATES_VILLAGE = "23077"
EXCELSIOR_SPRINGS_CITY = "23086"
EXETER_CITY = "23122"
FAIR_GROVE_CITY = "23338"
FAIR_PLAY_CITY = "23428"
FAIRDEALING_CDP = "23248"
FAIRFAX_CITY = "23266"
FAIRVIEW_TOWN = "23518"
FARBER_CITY = "23662"
FARLEY_VILLAGE = "23698"
FARMINGTON_CITY = "23752"
FAUCETT_CDP = "23824"
FAYETTE_CITY = "23842"
FENTON_CITY = "23950"
FERGUSON_CITY = "23986"
FERRELVIEW_VILLAGE = "24058"
FESTUS_CITY = "24094"
FIDELITY_TOWN = "24120"
FILLMORE_CITY = "24184"
FISK_CITY = "24328"
FLEMING_CITY = "24562"
FLEMINGTON_VILLAGE = "24580"
FLINT_HILL_CITY = "24688"
FLORDELL_HILLS_CITY = "24706"
FLORIDA_VILLAGE = "24760"
FLORISSANT_CITY = "24778"
FOLEY_CITY = "24886"
FORDLAND_CITY = "25012"
FOREST_CITY_CITY = "25066"
FORISTELL_CITY = "25120"
FORSYTH_CITY = "25192"
FORT_LEONARD_WOOD_CDP = "25264"
FORTESCUE_TOWN = "25228"
FORTUNA_CDP = "25300"
FOSTER_VILLAGE = "25372"
FOUNTAIN_N_LAKES_VILLAGE = "25411"
FRANKCLAY_CDP = "25516"
FRANKFORD_CITY = "25552"
FRANKLIN_CITY = "25624"
FREDERICKTOWN_CITY = "25768"
FREEBURG_VILLAGE = "25822"
FREEMAN_CITY = "25894"
FREISTATT_VILLAGE = "25912"
FREMONT_CDP = "25948"
FREMONT_HILLS_CITY = "25957"
FRIEDENSWALD_VILLAGE = "26000"
FRISBEE_CDP = "26020"
FROHNA_CITY = "26092"
FRONTENAC_CITY = "26110"
FULTON_CITY = "26182"
GAINESVILLE_CITY = "26218"
GALENA_CITY = "26254"
GALLATIN_CITY = "26308"
GALT_CITY = "26362"
GARDEN_CITY_CITY = "26434"
GASCONADE_CITY = "26578"
GENTRY_VILLAGE = "26776"
GERALD_CITY = "26866"
GERSTER_TOWN = "26902"
GIBBS_VILLAGE = "26920"
GIDEON_CITY = "26974"
GILLIAM_CITY = "27028"
GILMAN_CITY_CITY = "27064"
GINGER_BLUE_VILLAGE = "27100"
GLADSTONE_CITY = "27190"
GLASGOW_VILLAGE_CDP = "27226"
GLASGOW_CITY = "27208"
GLEN_ALLEN_TOWN = "27280"
GLEN_ECHO_PARK_VILLAGE = "27370"
GLENAIRE_CITY = "27262"
GLENDALE_CITY = "27334"
GLENWOOD_VILLAGE = "27514"
GOLDEN_CDP = "27658"
GOLDEN_CITY_CITY = "27676"
GOODMAN_CITY = "27874"
GOOSE_CREEK_LAKE_CDP = "27924"
GORDONVILLE_VILLAGE = "27928"
GOSS_TOWN = "28000"
GOWER_CITY = "28036"
GRAHAM_TOWN = "28072"
GRAIN_VALLEY_CITY = "28090"
GRANBY_CITY = "28108"
GRAND_FALLS_PLAZA_TOWN = "28170"
GRAND_PASS_VILLAGE = "28198"
GRANDIN_CITY = "28180"
GRANDVIEW_CITY = "28324"
GRANGER_VILLAGE = "28360"
GRANT_CITY_TOWN = "28594"
GRANTWOOD_VILLAGE_TOWN = "28630"
GRAVOIS_MILLS_TOWN = "28828"
GRAY_SUMMIT_CDP = "28918"
GRAYHAWK_CDP = "28860"
GRAYRIDGE_CDP = "28864"
GRAYSON_CDP = "28882"
GREEN_CITY_CITY = "29134"
GREEN_PARK_CITY = "29324"
GREEN_RIDGE_CITY = "29332"
GREENCASTLE_CITY = "29116"
GREENDALE_CITY = "29152"
GREENFIELD_CITY = "29206"
GREENTOP_CITY = "29422"
GREENVILLE_CITY = "29476"
GREENWOOD_CITY = "29494"
GROVESPRING_CDP = "29656"
GUILFORD_TOWN = "29692"
GUNN_CITY_VILLAGE = "29764"
HALE_CITY = "29908"
HALFWAY_VILLAGE = "29962"
HALLSVILLE_CITY = "29998"
HALLTOWN_VILLAGE = "30016"
HAMILTON_CITY = "30034"
HANLEY_HILLS_VILLAGE = "30196"
HANNIBAL_CITY = "30214"
HARDIN_CITY = "30322"
HARRIS_TOWN = "30466"
HARRISBURG_TOWN = "30484"
HARRISONVILLE_CITY = "30610"
HARTSBURG_TOWN = "30718"
HARTVILLE_CITY = "30754"
HARTWELL_CDP = "30772"
HARVIELL_CDP = "30844"
HARWOOD_VILLAGE = "30862"
HAWK_POINT_CITY = "31024"
HAYTI_HEIGHTS_CITY = "31168"
HAYTI_CITY = "31132"
HAYWARD_CDP = "31186"
HAYWOOD_CITY_VILLAGE = "31204"
HAZELWOOD_CITY = "31276"
HENRIETTA_CITY = "31654"
HERCULANEUM_CITY = "31708"
HERMANN_CITY = "31762"
HERMITAGE_CITY = "31780"
HIGBEE_CITY = "31924"
HIGGINSVILLE_CITY = "31960"
HIGH_HILL_CITY = "31996"
HIGH_RIDGE_CDP = "32140"
HIGHLANDVILLE_CITY = "32068"
HILLSBORO_CITY = "32248"
HILLSDALE_VILLAGE = "32266"
HOBERG_VILLAGE = "32410"
HOLCOMB_CITY = "32536"
HOLDEN_CITY = "32572"
HOLLAND_TOWN = "32590"
HOLLIDAY_VILLAGE = "32626"
HOLLISTER_CITY = "32662"
HOLLYWOOD_CDP = "32698"
HOLT_CITY = "32752"
HOLTS_SUMMIT_CITY = "32770"
HOMESTEAD_VILLAGE = "32806"
HOMESTOWN_CITY = "32824"
HOPKINS_CITY = "33004"
HORINE_CDP = "33040"
HORNERSVILLE_CITY = "33076"
HOUSTON_LAKE_CITY = "33292"
HOUSTON_CITY = "33238"
HOUSTONIA_CITY = "33256"
HOWARDVILLE_CITY = "33364"
HUGHESVILLE_VILLAGE = "33652"
HUMANSVILLE_CITY = "33706"
HUME_TOWN = "33724"
HUMPHREYS_VILLAGE = "33742"
HUNNEWELL_CITY = "33760"
HUNTER_CDP = "33778"
HUNTLEIGH_CITY = "33850"
HUNTSDALE_TOWN = "33868"
HUNTSVILLE_CITY = "33886"
HURDLAND_CITY = "33904"
HURLEY_CITY = "33922"
IANTHA_CDP = "34192"
IATAN_VILLAGE = "34210"
IBERIA_CITY = "34228"
IMPERIAL_CDP = "34354"
INDEPENDENCE_CITY = "35000"
INDIAN_LAKE_CDP = "35180"
INDIAN_POINT_VILLAGE = "35186"
INNSBROOK_VILLAGE = "35240"
IONIA_TOWN = "35306"
IRENA_VILLAGE = "35324"
IRON_MOUNTAIN_LAKE_CITY = "35450"
IRONDALE_CITY = "35396"
IRONTON_CITY = "35468"
IRWIN_CDP = "35486"
JACKSON_CITY = "35648"
JACKSONVILLE_VILLAGE = "36224"
JAMESON_TOWN = "36314"
JAMESPORT_CITY = "36332"
JAMESTOWN_TOWN = "36368"
JANE_TOWN = "36422"
JASPER_CITY = "36512"
JEFFERSON_CITY_CITY = "37000"
JENNINGS_CITY = "37178"
JERICO_SPRINGS_VILLAGE = "37214"
JONESBURG_CITY = "37574"
JOPLIN_CITY = "37592"
JOSEPHVILLE_VILLAGE = "37700"
JUNCTION_CITY_VILLAGE = "37736"
KAHOKA_CITY = "37790"
KANSAS_CITY_CITY = "38000"
KEARNEY_CITY = "38072"
KELSO_VILLAGE = "38216"
KENNETT_CITY = "38306"
KEYTESVILLE_CITY = "38468"
KIDDER_CITY = "38522"
KIMBERLING_CITY_CITY = "38612"
KIMMSWICK_CITY = "38684"
KING_CITY_CITY = "38774"
KINGDOM_CITY_VILLAGE = "38792"
KINGSTON_CITY = "38846"
KINGSVILLE_CITY = "38918"
KINLOCH_CITY = "38972"
KIRBYVILLE_VILLAGE = "39008"
KIRKSVILLE_CITY = "39026"
KIRKWOOD_CITY = "39044"
KISSEE_MILLS_CDP = "39080"
KNOB_LICK_CDP = "39170"
KNOB_NOSTER_CITY = "39188"
KNOX_CITY_CITY = "39278"
KOSHKONONG_TOWN = "39440"
LA_BELLE_CITY = "39512"
LA_DUE_VILLAGE = "39638"
LA_GRANGE_CITY = "39764"
LA_MONTE_CITY = "40520"
LA_PLATA_CITY = "40682"
LA_RUSSELL_CITY = "40790"
LA_TOUR_CDP = "40880"
LABARQUE_CREEK_CDP = "39503"
LACLEDE_CITY = "39566"
LADDONIA_CITY = "39602"
LADUE_CITY = "39656"
LAKE_ANNETTE_CITY = "39845"
LAKE_ARROWHEAD_CDP = "39852"
LAKE_LAFAYETTE_CITY = "39952"
LAKE_LOTAWANA_CITY = "39980"
LAKE_OZARK_CITY = "40034"
LAKE_ST_CLAIR_CDP = "40039"
LAKE_ST_LOUIS_CITY = "40043"
LAKE_TAPAWINGO_CITY = "40196"
LAKE_TEKAKWITHA_VILLAGE = "40214"
LAKE_TIMBERLINE_CDP = "40222"
LAKE_VIKING_CDP = "40304"
LAKE_WAUKOMIS_CITY = "40322"
LAKE_WINNEBAGO_CITY = "40340"
LAKESHIRE_CITY = "40088"
LAKESIDE_CITY = "40142"
LAMAR_HEIGHTS_CITY = "40430"
LAMAR_CITY = "40376"
LAMBERT_VILLAGE = "40448"
LANAGAN_TOWN = "40592"
LANCASTER_CITY = "40610"
LAREDO_CITY = "40736"
LATHAM_CDP = "40808"
LATHROP_CITY = "40826"
LAURIE_CITY = "40916"
LAWSON_CITY = "40988"
LEADINGTON_CITY = "41024"
LEADWOOD_CITY = "41078"
LEASBURG_VILLAGE = "41114"
LEAWOOD_VILLAGE = "41132"
LEBANON_CITY = "41168"
LEES_SUMMIT_CITY = "41348"
LEETON_CITY = "41402"
LEISURE_LAKE_CDP = "41417"
LEMAY_CDP = "41438"
LEONARD_VILLAGE = "41546"
LESLIE_VILLAGE = "41690"
LEVASY_CITY = "41762"
LEWIS_AND_CLARK_VILLAGE_TOWN = "41834"
LEWISTOWN_TOWN = "41852"
LEXINGTON_CITY = "41870"
LIBERAL_CITY = "41906"
LIBERTY_CITY = "42032"
LICKING_CITY = "42464"
LILBOURN_CITY = "42536"
LINCOLN_CITY = "42608"
LINN_CREEK_CITY = "43274"
LINN_CITY = "43238"
LINNEUS_CITY = "43292"
LITHIUM_CDP = "43346"
LIVONIA_VILLAGE = "43454"
LOCH_LLOYD_VILLAGE = "43468"
LOCK_SPRINGS_VILLAGE = "43472"
LOCKWOOD_CITY = "43490"
LOHMAN_CITY = "43652"
LOMA_LINDA_TOWN = "43672"
LONE_JACK_CITY = "43760"
LONGTOWN_TOWN = "43940"
LOUISBURG_VILLAGE = "44156"
LOUISIANA_CITY = "44174"
LOWRY_CITY_CITY = "44282"
LUCERNE_VILLAGE = "44372"
LUDLOW_TOWN = "44390"
LUPUS_TOWN = "44498"
LURAY_VILLAGE = "44516"
MACKS_CREEK_CDP = "45218"
MACON_CITY = "45326"
MADISON_CITY = "45470"
MAITLAND_CITY = "45596"
MALDEN_CITY = "45614"
MALTA_BEND_TOWN = "45632"
MANCHESTER_CITY = "45668"
MANSFIELD_CITY = "45740"
MAPLEWOOD_CITY = "45830"
MARBLE_HILL_CITY = "45848"
MARCELINE_CITY = "45866"
MARIONVILLE_CITY = "46172"
MARLBOROUGH_VILLAGE = "46208"
MARQUAND_CITY = "46244"
MARSHALL_CITY = "46316"
MARSHFIELD_CITY = "46388"
MARSTON_CITY = "46406"
MARTHASVILLE_CITY = "46424"
MARTINSBURG_TOWN = "46460"
MARYLAND_HEIGHTS_CITY = "46586"
MARYVILLE_CITY = "46640"
MATTHEWS_CITY = "46730"
MAYSVILLE_CITY = "46946"
MAYVIEW_CITY = "46964"
MCBAINE_TOWN = "44768"
MCCORD_BEND_VILLAGE = "44829"
MCFALL_CITY = "45020"
MCKITTRICK_TOWN = "45200"
MEADVILLE_CITY = "47036"
MEDILL_CDP = "47144"
MEHLVILLE_CDP = "47180"
MEMPHIS_CITY = "47270"
MENDON_CITY = "47288"
MERCER_TOWN = "47486"
MERRIAM_WOODS_CITY = "47520"
MERWIN_VILLAGE = "47540"
META_CITY = "47594"
METZ_TOWN = "47612"
MEXICO_CITY = "47648"
MIAMI_CITY = "47684"
MIDDLE_GROVE_CDP = "47846"
MIDDLETOWN_TOWN = "47900"
MILAN_CITY = "48062"
MILFORD_VILLAGE = "48098"
MILL_SPRING_VILLAGE = "48386"
MILLARD_VILLAGE = "48134"
MILLER_CITY = "48242"
MILLERSVILLE_CDP = "48350"
MILO_VILLAGE = "48476"
MINDENMINES_CITY = "48566"
MINE_LA_MOTTE_CDP = "48602"
MINER_CITY = "48656"
MINERAL_POINT_TOWN = "48710"
MIRAMIGUOA_PARK_VILLAGE = "48880"
MISSOURI_CITY_CITY = "48980"
MOBERLY_CITY = "49034"
MOKANE_CITY = "49070"
MOLINE_ACRES_CITY = "49088"
MONETT_CITY = "49196"
MONROE_CITY_CITY = "49394"
MONTGOMERY_CITY_CITY = "49574"
MONTICELLO_VILLAGE = "49592"
MONTIER_CDP = "49610"
MONTREAL_CDP = "49646"
MONTROSE_CITY = "49664"
MOORESVILLE_VILLAGE = "49790"
MOREHOUSE_CITY = "49898"
MORLEY_CITY = "49988"
MORRISON_CITY = "50060"
MORRISVILLE_TOWN = "50078"
MOSBY_CITY = "50168"
MOSCOW_MILLS_CITY = "50204"
MOUND_CITY_CITY = "50312"
MOUNDVILLE_TOWN = "50330"
MOUNT_LEONARD_TOWN = "50510"
MOUNT_MORIAH_TOWN = "50528"
MOUNT_VERNON_CITY = "50672"
MOUNTAIN_GROVE_CITY = "50402"
MOUNTAIN_VIEW_CITY = "50438"
MURPHY_CDP = "50834"
NAPOLEON_CITY = "51140"
NAYLOR_CITY = "51302"
NECK_CITY_CITY = "51356"
NEELYVILLE_CITY = "51446"
NELSON_CITY = "51500"
NEOSHO_CITY = "51572"
NEVADA_CITY = "51644"
NEW_BLOOMFIELD_CITY = "51680"
NEW_CAMBRIA_CITY = "51734"
NEW_FLORENCE_CITY = "51770"
NEW_FRANKLIN_CITY = "51824"
NEW_HAMBURG_CDP = "51842"
NEW_HAMPTON_CITY = "51860"
NEW_HAVEN_CITY = "51914"
NEW_LONDON_CITY = "52058"
NEW_MADRID_CITY = "52076"
NEW_MARKET_CDP = "52130"
NEW_MELLE_CITY = "52148"
NEW_WELLS_CDP = "52364"
NEWARK_VILLAGE = "51662"
NEWBURG_CITY = "51716"
NEWTONIA_TOWN = "52292"
NEWTOWN_TOWN = "52328"
NIANGUA_CITY = "52418"
NIXA_CITY = "52616"
NOEL_CITY = "52742"
NORBORNE_CITY = "52760"
NORMANDY_CITY = "52796"
NORTH_KANSAS_CITY_CITY = "53102"
NORTH_LILBOURN_VILLAGE = "53138"
NORTHMOOR_CITY = "53174"
NORTHWOODS_CITY = "53408"
NORWOOD_COURT_TOWN = "53462"
NORWOOD_CITY = "53454"
NOVELTY_VILLAGE = "53516"
NOVINGER_CITY = "53534"
OFALLON_CITY = "54074"
OAK_GROVE_VILLAGE_VILLAGE = "53650"
OAK_GROVE_CITY = "53624"
OAK_RIDGE_TOWN = "53786"
OAKLAND_CITY = "53750"
OAKS_VILLAGE = "53804"
OAKVIEW_VILLAGE = "53858"
OAKVILLE_CDP = "53876"
OAKWOOD_PARK_VILLAGE = "53948"
OAKWOOD_VILLAGE = "53894"
ODESSA_CITY = "54038"
OLD_APPLETON_TOWN = "54200"
OLD_JAMESTOWN_CDP = "54352"
OLD_MONROE_CITY = "54416"
OLEAN_TOWN = "54560"
OLIVETTE_CITY = "54650"
OLYMPIAN_VILLAGE_CITY = "54686"
ORAN_CITY = "54758"
OREGON_CITY = "54848"
ORONOGO_CITY = "54920"
ORRICK_CITY = "54938"
OSAGE_BEACH_CITY = "55244"
OSBORN_CITY = "55352"
OSCEOLA_CITY = "55388"
OSGOOD_VILLAGE = "55424"
OTTERVILLE_CITY = "55478"
OVERLAND_CITY = "55550"
OWENSVILLE_CITY = "55640"
OXLY_CDP = "55694"
OZARK_CITY = "55766"
OZORA_CDP = "55892"
PACIFIC_CITY = "55910"
PAGEDALE_CITY = "55964"
PALMYRA_CITY = "56036"
PARADISE_CDP = "56126"
PARIS_CITY = "56144"
PARK_HILLS_CITY = "56272"
PARKDALE_VILLAGE = "56226"
PARKVILLE_CITY = "56288"
PARKWAY_VILLAGE = "56306"
PARMA_CITY = "56342"
PARNELL_CITY = "56360"
PASADENA_HILLS_CITY = "56396"
PASADENA_PARK_VILLAGE = "56414"
PASCOLA_VILLAGE = "56432"
PASSAIC_TOWN = "56468"
PATTONSBURG_CITY = "56558"
PAYNESVILLE_VILLAGE = "56612"
PEACEFUL_VILLAGE_VILLAGE = "56620"
PECULIAR_CITY = "56756"
PENDLETON_VILLAGE = "56882"
PENERMON_VILLAGE = "56900"
PERKINS_CDP = "57044"
PERRY_CITY = "57080"
PERRYVILLE_CITY = "57116"
PEVELY_CITY = "57278"
PHELPS_CITY_CDP = "57332"
PHILADELPHIA_CDP = "57350"
PHILLIPSBURG_VILLAGE = "57368"
PICKERING_CITY = "57404"
PIEDMONT_CITY = "57422"
PIERCE_CITY_CITY = "57494"
PIERPONT_VILLAGE = "57512"
PILOT_GROVE_CITY = "57602"
PILOT_KNOB_CITY = "57656"
PINE_LAWN_CITY = "57800"
PINEVILLE_CITY = "57818"
PINHOOK_VILLAGE = "57926"
PLATO_VILLAGE = "58088"
PLATTE_CITY_CITY = "58178"
PLATTE_WOODS_CITY = "58196"
PLATTSBURG_CITY = "58250"
PLEASANT_HILL_CITY = "58394"
PLEASANT_HOPE_CITY = "58448"
PLEASANT_VALLEY_CITY = "58520"
PLEVNA_CDP = "58574"
POCAHONTAS_TOWN = "58628"
POLLOCK_VILLAGE = "58898"
POLO_CITY = "58916"
POMONA_CDP = "58934"
PONTIAC_CDP = "59060"
POPLAR_BLUFF_CITY = "59096"
PORTAGE_DES_SIOUX_CITY = "59150"
PORTAGEVILLE_CITY = "59186"
POTOSI_CITY = "59330"
POWERSVILLE_VILLAGE = "59420"
PRAIRIE_HILL_CDP = "59708"
PRAIRIE_HOME_CITY = "59726"
PRATHERSVILLE_VILLAGE = "59816"
PRESTON_VILLAGE = "59870"
PRINCETON_CITY = "59942"
PURCELL_CITY = "60140"
PURDIN_CITY = "60158"
PURDY_CITY = "60176"
PUXICO_CITY = "60284"
QUEEN_CITY_CITY = "60356"
QUITMAN_CDP = "60410"
QULIN_CITY = "60428"
RAINTREE_PLANTATION_CDP = "60528"
RANDOLPH_VILLAGE = "60590"
RAVANNA_CDP = "60644"
RAVENWOOD_TOWN = "60716"
RAYMONDVILLE_TOWN = "60734"
RAYMORE_CITY = "60752"
RAYTOWN_CITY = "60788"
RAYVILLE_CDP = "60824"
REA_CITY = "60842"
REDINGS_MILL_VILLAGE = "60986"
REEDS_SPRING_CITY = "61112"
REEDS_TOWN = "61094"
RENICK_VILLAGE = "61166"
RENSSELAER_VILLAGE = "61184"
REPUBLIC_CITY = "61238"
REVERE_TOWN = "61292"
RHINELAND_TOWN = "61328"
RICH_HILL_CITY = "61418"
RICHARDS_TOWN = "61364"
RICHLAND_CITY = "61562"
RICHMOND_HEIGHTS_CITY = "61706"
RICHMOND_CITY = "61670"
RIDGELY_VILLAGE = "61886"
RIDGEWAY_CITY = "61904"
RISCO_CITY = "61994"
RITCHEY_TOWN = "62030"
RIVER_BEND_VILLAGE = "62056"
RIVERSIDE_CITY = "62156"
RIVERVIEW_ESTATES_VILLAGE = "62210"
RIVERVIEW_VILLAGE = "62192"
RIVES_TOWN = "62228"
ROCHEPORT_CITY = "62498"
ROCK_HILL_CITY = "62660"
ROCK_PORT_CITY = "62696"
ROCKAWAY_BEACH_CITY = "62570"
ROCKVILLE_CITY = "62786"
ROCKY_COMFORT_CDP = "62822"
ROGERSVILLE_CITY = "62894"
ROLLA_CITY = "62912"
ROSCOE_VILLAGE = "63074"
ROSEBUD_CITY = "63110"
ROSENDALE_CITY = "63200"
ROTHVILLE_VILLAGE = "63236"
RUSH_HILL_VILLAGE = "63560"
RUSHVILLE_VILLAGE = "63596"
RUSSELLVILLE_CITY = "63704"
RUTLEDGE_TOWN = "63776"
SADDLEBROOKE_VILLAGE = "63857"
SAGINAW_VILLAGE = "63902"
SALEM_CITY = "65234"
SALISBURY_CITY = "65450"
SAPPINGTON_CDP = "65954"
SARCOXIE_CITY = "65990"
SAVANNAH_CITY = "66044"
SAVERTON_CDP = "66062"
SCHELL_CITY_CITY = "66134"
SCOTSDALE_TOWN = "66337"
SCOTT_CITY_CITY = "66368"
SEDALIA_CITY = "66440"
SEDGEWICKVILLE_VILLAGE = "66476"
SELIGMAN_CITY = "66530"
SENATH_CITY = "66638"
SENECA_CITY = "66674"
SEYMOUR_CITY = "66800"
SHAKERTOWNE_CDP = "66935"
SHAWNEETOWN_CDP = "67124"
SHELBINA_CITY = "67178"
SHELBYVILLE_CITY = "67196"
SHELDON_CITY = "67214"
SHELL_KNOB_CDP = "67232"
SHERIDAN_TOWN = "67358"
SHOAL_CREEK_DRIVE_VILLAGE = "67628"
SHOAL_CREEK_ESTATES_VILLAGE = "67632"
SHREWSBURY_CITY = "67700"
SIBLEY_VILLAGE = "67718"
SIKESTON_CITY = "67790"
SILEX_CITY = "67808"
SKIDMORE_CITY = "68132"
SLATER_CITY = "68204"
SMITHTON_CITY = "68384"
SMITHVILLE_CITY = "68420"
SOUTH_FORK_CDP = "68762"
SOUTH_GIFFORD_VILLAGE = "68852"
SOUTH_GORIN_TOWN = "68870"
SOUTH_GREENFIELD_VILLAGE = "68888"
SOUTH_LINEVILLE_TOWN = "68942"
SOUTHWEST_CITY_TOWN = "69230"
SPANISH_LAKE_CDP = "69266"
SPARTA_CITY = "69302"
SPICKARD_CITY = "69464"
SPOKANE_CDP = "69518"
SPRINGFIELD_CITY = "70000"
ST_ANN_CITY = "63956"
ST_CATHARINE_CDP = "64046"
ST_CHARLES_CITY = "64082"
ST_CLAIR_CITY = "64136"
ST_CLEMENT_CDP = "64154"
ST_CLOUD_VILLAGE = "64172"
ST_ELIZABETH_VILLAGE = "64190"
ST_FRANCISVILLE_CDP = "64244"
ST_GEORGE_CDP = "64370"
ST_JAMES_CITY = "64424"
ST_JOHN_CITY = "64478"
ST_JOSEPH_CITY = "64550"
ST_LOUIS_CITY = "65000"
ST_MARTINS_CITY = "65018"
ST_MARY_CITY = "65034"
ST_PAUL_CITY = "65108"
ST_PETERS_CITY = "65126"
ST_ROBERT_CITY = "65144"
ST_THOMAS_TOWN = "65162"
STANBERRY_CITY = "70270"
STANTON_CDP = "70342"
STARK_CITY_TOWN = "70414"
STE_GENEVIEVE_CITY = "64180"
STEELE_CITY = "70558"
STEELVILLE_CITY = "70576"
STELLA_TOWN = "70648"
STEWARTSVILLE_CITY = "70738"
STOCKTON_CITY = "70828"
STOTESBURY_TOWN = "70954"
STOTTS_CITY_CITY = "70990"
STOUTLAND_CITY = "71008"
STOUTSVILLE_VILLAGE = "71026"
STOVER_CITY = "71044"
STRAFFORD_CITY = "71062"
STRASBURG_CITY = "71098"
STURGEON_CITY = "71224"
SUGAR_CREEK_CITY = "71368"
SULLIVAN_CITY = "71440"
SUMMER_SET_CDP = "71508"
SUMMERSVILLE_CITY = "71512"
SUMNER_TOWN = "71620"
SUNDOWN_CDP = "71628"
SUNRISE_BEACH_VILLAGE = "71728"
SUNSET_HILLS_CITY = "71746"
SWEET_SPRINGS_CITY = "71890"
SYCAMORE_HILLS_VILLAGE = "72034"
SYRACUSE_CITY = "72106"
TALLAPOOSA_CITY = "72196"
TANEYVILLE_VILLAGE = "72232"
TAOS_CITY = "72304"
TARKIO_CITY = "72340"
TARRANTS_VILLAGE = "72376"
TARSNEY_LAKES_CDP = "72412"
TEBBETTS_CDP = "72574"
TERRE_DU_LAC_CDP = "72772"
THAYER_CITY = "72826"
THEODOSIA_VILLAGE = "72898"
THOMASVILLE_CDP = "73006"
THREE_CREEKS_VILLAGE = "73127"
TIGHTWAD_VILLAGE = "73240"
TINA_VILLAGE = "73330"
TINDALL_TOWN = "73348"
TIPTON_CITY = "73420"
TOWN_AND_COUNTRY_CITY = "73618"
TRACY_CITY = "73690"
TRENTON_CITY = "73816"
TRIMBLE_CITY = "73852"
TRIPLETT_CITY = "73870"
TROY_CITY = "73942"
TRUESDALE_CITY = "73978"
TRUXTON_VILLAGE = "74014"
TURNEY_VILLAGE = "74176"
TUSCUMBIA_TOWN = "74194"
TWIN_OAKS_VILLAGE = "74284"
UMBER_VIEW_HEIGHTS_VILLAGE = "74473"
UNION_STAR_TOWN = "75130"
UNION_CITY = "74626"
UNIONVILLE_CITY = "75166"
UNITY_VILLAGE_VILLAGE = "75202"
UNIVERSITY_CITY_CITY = "75220"
UPLANDS_PARK_VILLAGE = "75238"
URBANA_CITY = "75310"
URICH_CITY = "75346"
UTICA_VILLAGE = "75364"
VALLEY_PARK_CITY = "75472"
VAN_BUREN_TOWN = "75580"
VANDALIA_CITY = "75688"
VANDIVER_VILLAGE = "75706"
VANDUSER_VILLAGE = "75724"
VELDA_CITY_CITY = "75796"
VELDA_VILLAGE_HILLS_CITY = "75814"
VERONA_TOWN = "75886"
VERSAILLES_CITY = "75922"
VIBBARD_CDP = "75994"
VIBURNUM_CITY = "76012"
VIENNA_CITY = "76102"
VILLA_RIDGE_CDP = "76192"
VILLAGE_OF_FOUR_SEASONS_VILLAGE = "76157"
VINITA_PARK_CITY = "76246"
VISTA_VILLAGE = "76390"
WACO_CITY = "76444"
WALKER_CITY = "76660"
WALNUT_GROVE_CITY = "76840"
WARDELL_TOWN = "76966"
WARDSVILLE_VILLAGE = "77002"
WARRENSBURG_CITY = "77092"
WARRENTON_CITY = "77128"
WARSAW_CITY = "77146"
WARSON_WOODS_CITY = "77182"
WASHBURN_CITY = "77200"
WASHINGTON_CITY = "77416"
WASOLA_CDP = "77794"
WATSON_VILLAGE = "77848"
WAVERLY_CITY = "77866"
WAYLAND_CITY = "77920"
WAYNESVILLE_CITY = "77992"
WEATHERBY_LAKE_CITY = "78046"
WEATHERBY_TOWN = "78028"
WEAUBLEAU_CITY = "78064"
WEBB_CITY_CITY = "78118"
WEBSTER_GROVES_CITY = "78154"
WEINGARTEN_CDP = "78226"
WELDON_SPRING_HEIGHTS_TOWN = "78334"
WELDON_SPRING_CITY = "78314"
WELLINGTON_CITY = "78352"
WELLSTON_CITY = "78370"
WELLSVILLE_CITY = "78406"
WENTWORTH_VILLAGE = "78424"
WENTZVILLE_CITY = "78442"
WEST_ALTON_CITY = "78514"
WEST_LINE_VILLAGE = "78838"
WEST_PLAINS_CITY = "78928"
WEST_SULLIVAN_TOWN = "79000"
WESTBORO_CITY = "78622"
WESTON_CITY = "78856"
WESTPHALIA_CITY = "78910"
WESTWOOD_VILLAGE = "79054"
WHEATLAND_CITY = "79090"
WHEATON_CITY = "79126"
WHEELING_CITY = "79180"
WHITE_BRANCH_CDP = "79288"
WHITE_OAK_CDP = "79468"
WHITEMAN_AFB_CDP = "79432"
WHITESIDE_VILLAGE = "79558"
WHITEWATER_TOWN = "79612"
WHITING_CDP = "79684"
WILBUR_PARK_VILLAGE = "79756"
WILDWOOD_CITY = "79820"
WILLARD_CITY = "79882"
WILLIAMSTOWN_CDP = "80008"
WILLIAMSVILLE_CITY = "80026"
WILLOW_SPRINGS_CITY = "80098"
WILSON_CITY_VILLAGE = "80260"
WINCHESTER_CITY = "80314"
WINDSOR_PLACE_VILLAGE = "80380"
WINDSOR_CITY = "80350"
WINFIELD_CITY = "80422"
WINIGAN_CDP = "80440"
WINONA_CITY = "80512"
WINSTON_VILLAGE = "80548"
WOOD_HEIGHTS_CITY = "80767"
WOODSON_TERRACE_CITY = "80962"
WOOLDRIDGE_VILLAGE = "81016"
WORTH_VILLAGE = "81070"
WORTHAM_CDP = "81088"
WORTHINGTON_VILLAGE = "81106"
WRIGHT_CITY_CITY = "81124"
WYACONDA_CITY = "81142"
WYATT_CITY = "81178"
ZALMA_CDP = "81430"



# Copyright (c) 2023 Darren Erik Vengroff
"""
Counties in Connecticut.

Connecticut is a little different than other states because in 2022,
the U.S. Census, at the state's request, began tracking planning
regions as county-like divisions.

We support both symbolically. Which one you get back from the census for
county queries will depend on the data set and vintage.

See
https://www.federalregister.gov/documents/2022/06/06/2022-12063/change-to-county-equivalents-in-the-state-of-connecticut
for more on this.
"""

# Pre-2022 counties.
FAIRFIELD = "001"
HARTFORD = "003"
LITCHFIELD = "005"
MIDDLESEX = "007"
NEW_HAVEN = "009"
NEW_LONDON = "011"
TOLLAND = "013"
WINDHAM = "015"

# Post-2020 planning regions.
CAPITOL_PLANNING_REGION = "110"
GREATER_BRIDGEPORT_PLANNING_REGION = "120"
LOWER_CONNECTICUT_RIVER_VALLEY_PLANNING_REGION = "130"
NAUGATUCK_VALLEY_PLANNING_REGION = "140"
NORTHEASTERN_CONNECTICUT_PLANNING_REGION = "150"
NORTHWEST_HILLS_PLANNING_REGION = "160"
SOUTH_CENTRAL_CONNECTICUT_PLANNING_REGION = "170"
SOUTHEASTERN_CONNECTICUT_PLANNING_REGION = "180"
WESTERN_CONNECTICUT_PLANNING_REGION = "190"
